aboutsummaryrefslogtreecommitdiff
path: root/js/reveal.js
diff options
context:
space:
mode:
authorHakim El Hattab <hakim.elhattab@gmail.com>2012-10-13 12:13:26 -0400
committerHakim El Hattab <hakim.elhattab@gmail.com>2012-10-13 12:13:26 -0400
commit6e0d0e279d04c2e7524b0131d5b463aa596cf57c (patch)
tree5fae83f10e59a56d4e16917021c57b1087b2369a /js/reveal.js
parent421b78aafb2e2c00af4d771c988347964675ef42 (diff)
downloadfosdem-2018-presentation-6e0d0e279d04c2e7524b0131d5b463aa596cf57c.tar
fosdem-2018-presentation-6e0d0e279d04c2e7524b0131d5b463aa596cf57c.tar.gz
roll back attr name change, just lowercase (#170)
Diffstat (limited to 'js/reveal.js')
-rw-r--r--js/reveal.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/js/reveal.js b/js/reveal.js
index aaad7c3..de5ebdc 100644
--- a/js/reveal.js
+++ b/js/reveal.js
@@ -34,7 +34,7 @@ var Reveal = (function(){
// Number of milliseconds between automatically proceeding to the
// next slide, disabled when set to 0, this value can be overwritten
// by using a data-duration attribute on your slides
autoSlide: 0,
// Enable slide navigation via mouse wheel
@@ -845,9 +845,9 @@ var Reveal = (function(){
state = state.concat( slideState.split( ' ' ) );
}
// If this slide has a data-duration attribtue associated use this as
// autoSlide value otherwise use the global configured time
- var slideAutoSlide = slides[index].getAttribute( 'data-duration' );
+ var slideAutoSlide = slides[index].getAttribute( 'data-autoslide' );
if( slideAutoSlide ) {
autoSlide = parseInt( slideAutoSlide );
} else {
@@ -34,7 +34,7 @@ var Reveal = (function(){
// Number of milliseconds between automatically proceeding to the
// next slide, disabled when set to 0, this value can be overwritten
- // by using a data-duration attribute on your slides
+ // by using a data-autoslide attribute on your slides
autoSlide: 0,
// Enable slide navigation via mouse wheel
@@ -845,9 +845,9 @@ var Reveal = (function(){
state = state.concat( slideState.split( ' ' ) );
}
- // If this slide has a data-duration attribtue associated use this as
+ // If this slide has a data-autoslide attribtue associated use this as
// autoSlide value otherwise use the global configured time